@@ -7,7 +7,7 @@ use Locale::TextDomain::OO;
 our $VERSION = 0;
 
 my $loc = Locale::TextDomain::OO->new(
-    plugins   => [ qw( Expand::Gettext ) ],
+    plugins   => [ qw( Expand::Gettext::Loc ) ],
     logger    => sub { () = print shift, "\n" },
     filter    => sub {
         my ( $self, $translation_ref ) = @_;
@@ -18,10 +18,10 @@ my $loc = Locale::TextDomain::OO->new(
 
 # translation with empty default lexicon i-default::
 () = print map { "$_\n" }
-    $loc->__('Hello World 1!'),
-    $loc->__('Hello World 2!');
+    $loc->loc_('Hello World 1!'),
+    $loc->loc_('Hello World 2!');
 
-#$Id: 02_filter.pl 456 2014-01-05 16:29:05Z steffenw $
+#$Id: 02_filter.pl 573 2015-02-07 20:59:51Z steffenw $
 
 __END__
 
