@@ -8,7 +8,7 @@ use Moo::Role;
 use MooX::Types::MooseLike::Base qw(Str);
 use namespace::autoclean;
 
-our $VERSION = '1.000';
+our $VERSION = '1.017';
 
 has filename => (
     is  => 'ro',
@@ -34,9 +34,9 @@ sub store_content {
         my $filename = $self->filename;
         open my $file_handle, q{> :raw}, $self->filename
             or confess qq{Unable to open file "$filename" $OS_ERROR};
-        $file_handle->print( $file_handle, $content )
+        $file_handle->print($content)
             or confess qq{Unable to print file "$filename" $OS_ERROR};
-        $file_handle->close( $file_handle, encode_json($content) )
+        $file_handle->close
             or confess qq{Unable to close file "$filename" $OS_ERROR};
         return;
     }
@@ -52,13 +52,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::Role::StoreFile - Role to store a lexicon as file
 
-$Id: StoreFile.pm 439 2013-12-19 20:42:34Z steffenw $
+$Id: StoreFile.pm 573 2015-02-07 20:59:51Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/Role/StoreFile.pm $
 
 =head1 VERSION
 
-1.000
+1.017
 
 =head1 DESCRIPTION
 
@@ -148,7 +148,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013,
+Copyright (c) 2013 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
