@@ -10,7 +10,7 @@ use Moo::Role;
 use MooX::Types::MooseLike::Base qw(HashRef);
 use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.017';
 
 for my $name ( qw( language category domain project ) ) {
     has "filter_$name" => (
@@ -88,10 +88,10 @@ my $prepare_lexicon = sub {
     for my $message_key ( keys %{$lexicon_ref} ) {
         length $message_key
             or next MESSAGE_KEY;
-        my $new_message_key = $key_util->join_message_key({(
-            %{ $key_util->split_message_key($message_key) },
-            format => 'JSON',
-        )});
+        my $new_message_key = $key_util->join_message_key(
+            $key_util->split_message_key($message_key),
+            'JSON',
+        );
         $lexicon_ref->{$new_message_key} = delete $lexicon_ref->{$message_key};
     }
 
@@ -131,13 +131,13 @@ __END__
 
 Locale::TextDomain::OO::Lexicon::Role::StoreFilter - Filters the lexicon data before stored
 
-$Id: StoreFilter.pm 546 2014-10-31 09:35:19Z steffenw $
+$Id: StoreFilter.pm 573 2015-02-07 20:59:51Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Lexicon/Role/StoreFilter.pm $
 
 =head1 VERSION
 
-1.014
+1.017
 
 =head1 DESCRIPTION
 
@@ -267,7 +267,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2013 - 2014,
+Copyright (c) 2013 - 2015,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
