@@ -3,12 +3,84 @@ package Locale::TextDomain::OO::TiedInterface; ## no critic (TidyCode)
 use strict;
 use warnings;
 
-our $VERSION = '1.000';
+our $VERSION = '1.014';
 
 use Carp qw(confess);
 use Tie::Sub;
 
 my %method_name = map { $_ => undef } qw(
+    loc_begin_d
+    loc_begin_c
+    loc_begin_dc
+    loc_end_d
+    loc_end_c
+    loc_end_dc
+    loc_
+    loc_x
+    loc_n
+    loc_nx
+    loc_p
+    loc_px
+    loc_np
+    loc_npx
+    loc_d
+    loc_dx
+    loc_dn
+    loc_dnx
+    loc_dp
+    loc_dpx
+    loc_dnp
+    loc_dnpx
+    loc_c
+    loc_cx
+    loc_cn
+    loc_cnx
+    loc_cp
+    loc_cpx
+    loc_cnp
+    loc_cnpx
+    loc_dc
+    loc_dcx
+    loc_dcn
+    loc_dcnx
+    loc_dcp
+    loc_dcpx
+    loc_dcnp
+    loc_dcnpx
+
+    Nloc_
+    Nloc_x
+    Nloc_n
+    Nloc_nx
+    Nloc_p
+    Nloc_px
+    Nloc_np
+    Nloc_npx
+    Nloc_d
+    Nloc_dx
+    Nloc_dn
+    Nloc_dnx
+    Nloc_dp
+    Nloc_dpx
+    Nloc_dnp
+    Nloc_dnpx
+    Nloc_c
+    Nloc_cx
+    Nloc_cn
+    Nloc_cnx
+    Nloc_cp
+    Nloc_cpx
+    Nloc_cnp
+    Nloc_cnpx
+    Nloc_dc
+    Nloc_dcx
+    Nloc_dcn
+    Nloc_dcnx
+    Nloc_dcp
+    Nloc_dcpx
+    Nloc_dcnp
+    Nloc_dcnpx
+
     __begin_d
     __begin_c
     __begin_dc
@@ -47,6 +119,7 @@ my %method_name = map { $_ => undef } qw(
     __dcpx
     __dcnp
     __dcnpx
+
     N__
     N__x
     N__n
@@ -79,18 +152,35 @@ my %method_name = map { $_ => undef } qw(
     N__dcpx
     N__dcnp
     N__dcnpx
+
+    locn
+    Nlocn
+
     maketext
     maketext_p
-    loc
-    loc_p
-    localize
-    localize_p
     Nmaketext
     Nmaketext_p
+
+    loc
+    loc_m
+    loc_mp
     Nloc
-    Nloc_p
+    Nloc_m
+    Nloc_mp
+
+    localise
+    localise_m
+    localise_mp
+    Nlocalise
+    Nlocalise_m
+    Nlocalise_mp
+
+    localize
+    localize_m
+    localize_mp
     Nlocalize
-    Nlocalize_p
+    Nlocalize_m
+    Nlocalize_mp
 );
 
 our $loc_ref = do { my $loc; \$loc }; ## no critic(PackageVars)
@@ -166,13 +256,13 @@ __END__
 
 Locale::TextDomain::OO::TiedInterface - Call object methods as tied hash
 
-$Id: TiedInterface.pm 268 2010-01-11 09:05:18Z steffenw $
+$Id: TiedInterface.pm 546 2014-10-31 09:35:19Z steffenw $
 
-$HeadURL: https://perl-gettext-oo.svn.sourceforge.net/svnroot/perl-gettext-oo/module/tags/0.07/lib/Locale/TextDomain/OO/TiedInterface.pm $
+$HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/TiedInterface.pm $
 
 =head1 VERSION
 
-1.000
+1.014
 
 =head1 DESCRIPTION
 
@@ -193,6 +283,78 @@ or import only the given variables, as example all
 
     use Locale::TextDomain::OO;
     use Locale::TextDomain::OO::TiedInterface $loc_ref, qw(
+        %loc_begin_d
+        %loc_begin_c
+        %loc_begin_dc
+        %loc_end_d
+        %loc_end_c
+        %loc_end_dc
+        %loc_
+        %loc_x
+        %loc_n
+        %loc_nx
+        %loc_p
+        %loc_px
+        %loc_np
+        %loc_npx
+        %loc_d
+        %loc_dx
+        %loc_dn
+        %loc_dnx
+        %loc_dp
+        %loc_dpx
+        %loc_dnp
+        %loc_dnpx
+        %loc_c
+        %loc_cx
+        %loc_cn
+        %loc_cnx
+        %loc_cp
+        %loc_cpx
+        %loc_cnp
+        %loc_cnpx
+        %loc_dc
+        %loc_dcx
+        %loc_dcn
+        %loc_dcnx
+        %loc_dcp
+        %loc_dcpx
+        %loc_dcnp
+        %loc_dcnpx
+
+        %Nloc_
+        %Nloc_x
+        %Nloc_n
+        %Nloc_nx
+        %Nloc_p
+        %Nloc_px
+        %Nloc_np
+        %Nloc_npx
+        %Nloc_d
+        %Nloc_dx
+        %Nloc_dn
+        %Nloc_dnx
+        %Nloc_dp
+        %Nloc_dpx
+        %Nloc_dnp
+        %Nloc_dnpx
+        %Nloc_c
+        %Nloc_cx
+        %Nloc_cn
+        %Nloc_cnx
+        %Nloc_cp
+        %Nloc_cpx
+        %Nloc_cnp
+        %Nloc_cnpx
+        %Nloc_dc
+        %Nloc_dcx
+        %Nloc_dcn
+        %Nloc_dcnx
+        %Nloc_dcp
+        %Nloc_dcpx
+        %Nloc_dcnp
+        %Nloc_dcnpx
+
         %__begin_d
         %__begin_c
         %__begin_dc
@@ -231,6 +393,7 @@ or import only the given variables, as example all
         %__dcpx
         %__dcnp
         %__dcnpx
+
         %N__
         %N__x
         %N__n
@@ -263,18 +426,108 @@ or import only the given variables, as example all
         %N__dcpx
         %N__dcnp
         %N__dcnpx
+
+        %locn
+        %Nlocn
+
         %maketext
         %maketext_p
-        %loc
-        %loc_p
-        %localize
-        %localize_p
         %Nmaketext
         %Nmaketext_p
+
+        %loc
+        %loc_m
+        %loc_mp
         %Nloc
-        %Nloc_p
+        %Nloc_m
+        %Nloc_mp
+
+        %localise
+        %localise_m
+        %localise_mp
+        %Nlocalise
+        %Nlocalise_m
+        %Nlocalise_mp
+
+        %localize
+        %localize_m
+        %localize_mp
         %Nlocalize
-        %Nlocalize_p
+        %Nlocalize_m
+        %Nlocalize_mp
+
+        $loc_begin_d
+        $loc_begin_c
+        $loc_begin_dc
+        $loc_end_d
+        $loc_end_c
+        $loc_end_dc
+        $loc_
+        $loc_x
+        $loc_n
+        $loc_nx
+        $loc_p
+        $loc_px
+        $loc_np
+        $loc_npx
+        $loc_d
+        $loc_dx
+        $loc_dn
+        $loc_dnx
+        $loc_dp
+        $loc_dpx
+        $loc_dnp
+        $loc_dnpx
+        $loc_c
+        $loc_cx
+        $loc_cn
+        $loc_cnx
+        $loc_cp
+        $loc_cpx
+        $loc_cnp
+        $loc_cnpx
+        $loc_dc
+        $loc_dcx
+        $loc_dcn
+        $loc_dcnx
+        $loc_dcp
+        $loc_dcpx
+        $loc_dcnp
+        $loc_dcnpx
+
+        $Nloc_
+        $Nloc_x
+        $Nloc_n
+        $Nloc_nx
+        $Nloc_p
+        $Nloc_px
+        $Nloc_np
+        $Nloc_npx
+        $Nloc_d
+        $Nloc_dx
+        $Nloc_dn
+        $Nloc_dnx
+        $Nloc_dp
+        $Nloc_dpx
+        $Nloc_dnp
+        $Nloc_dnpx
+        $Nloc_c
+        $Nloc_cx
+        $Nloc_cn
+        $Nloc_cnx
+        $Nloc_cp
+        $Nloc_cpx
+        $Nloc_cnp
+        $Nloc_cnpx
+        $Nloc_dc
+        $Nloc_dcx
+        $Nloc_dcn
+        $Nloc_dcnx
+        $Nloc_dcp
+        $Nloc_dcpx
+        $Nloc_dcnp
+        $Nloc_dcnpx
+
         $__begin_d
         $__begin_c
         $__begin_dc
@@ -313,6 +566,7 @@ or import only the given variables, as example all
         $__dcpx
         $__dcnp
         $__dcnpx
+
         $N__
         $N__x
         $N__n
@@ -345,18 +599,35 @@ or import only the given variables, as example all
         $N__dcpx
         $N__dcnp
         $N__dcnpx
+
+        $locn
+        $Nlocn
+
         $maketext
         $maketext_p
-        $loc
-        $loc_p
-        $localize
-        $localize_p
         $Nmaketext
         $Nmaketext_p
+
+        $loc
+        $loc_m
+        $loc_mp
         $Nloc
-        $Nloc_p
+        $Nloc_m
+        $Nloc_mp
+
+        $localise
+        $localise_m
+        $localise_mp
+        $Nlocalise
+        $Nlocalise_m
+        $Nlocalise_mp
+
+        $localize
+        $localize_m
+        $localize_mp
         $Nlocalize
-        $Nlocalize_p
+        $Nlocalize_m
+        $Nlocalize_mp
     );
     ${loc_ref} = Locale::TextDomain::OO->new(
         ...
@@ -403,7 +674,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009 - 2013,
+Copyright (c) 2009 - 2014,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
